@@ -14,7 +14,7 @@
 #' 
 #' @note
 #' This package relies on the usage of a running OSRM service (tested with 
-#' version 5.23.0 of the OSRM API).\cr
+#' version 5.26.0 of the OSRM API).\cr
 #' 
 #' 
 #' To set the OSRM server, change the \code{osrm.server} option:\cr 
@@ -27,33 +27,15 @@
 #' \code{options(osrm.server = "http://0.0.0.0:5000/", osrm.profile = "car")}
 #' 
 #' 
+#' 
+#' 
+#' The package ships a sample dataset of 100 random pharmacies in Berlin 
+#' (© OpenStreetMap contributors - \url{https://www.openstreetmap.org/copyright/en}).\cr   
+#' The sf dataset uses the projection WGS 84 / UTM zone 34N (EPSG:32634).\cr
+#' The csv dataset uses WGS 84 (EPSG:4326).\cr 
+#' 
+#' 
+#' 
 #' @docType package
 NULL
 
-
-#' @title sf POINT of 100 Random Pharmacies in Berlin
-#' @name apotheke.sf
-#' @description 100 random pharmacies in Berlin. 
-#' The projection is WGS 84 / UTM zone 34N.
-#' @import sf
-#' @source © OpenStreetMap contributors - \url{https://www.openstreetmap.org/copyright/en}.
-#' @docType data
-NULL
-
-
-#' @title SpatialPointsDataFrame of 100 Random Pharmacies in Berlin
-#' @name apotheke.sp
-#' @description 100 random pharmacies in Berlin. 
-#' The projection is WGS 84 / UTM zone 34N.
-#' @import sp
-#' @source © OpenStreetMap contributors - \url{https://www.openstreetmap.org/copyright/en}.
-#' @docType data
-NULL
-
-#' @title Coordinates of 100 Random Pharmacies in Berlin
-#' @name apotheke.df
-#' @description A data.frame of coordinates of 100 random pharmacies in Berlin. 
-#' The projection is WGS 84.
-#' @source © OpenStreetMap contributors - \url{https://www.openstreetmap.org/copyright/en}.
-#' @docType data
-NULL
