@@ -170,13 +170,16 @@ higher than 10000. Ask for fewer durations or use your own server and set its
 fewer durations or use your own server and set its --max-table-size option.")
   e3 <- simpleError("This request is to large for the public OSRM API. Ask for 
 fewer locations or use your own server and set its --max-trip-size option.")
-  if(getOption("osrm.server") == "https://routing.openstreetmap.de/" & (nSrc*nDst) > 10000){
+  if(getOption("osrm.server") == "https://routing.openstreetmap.de/" & (nSrc*nDst) > 9998){
     stop(e)
   }
   if(getOption("osrm.server") == "https://routing.openstreetmap.de/" & nreq >= 8000){
     stop(e2)
   }
-  if(getOption("osrm.server") == "https://routing.openstreetmap.de/" & nSrc > 100 & nDst==0){
+  if(getOption("osrm.server") == "https://routing.openstreetmap.de/" & nSrc > 99 & nDst==0){
+    stop(e3)
+  }
+  if(getOption("osrm.server") == "https://routing.openstreetmap.de/" & nSrc > 99 & nDst==0){
     stop(e3)
   }
 }
@@ -199,6 +202,7 @@ input_route <- function(x, id, single = TRUE){
       lat <- clean_coord(x[i+2])       
     }
     if(methods::is(x,"Spatial")){
+      warn_sp()
       x <- st_as_sf(x[1,])
     }
     if(is.data.frame(x)){
@@ -222,6 +226,7 @@ input_route <- function(x, id, single = TRUE){
     return(list(id = id, lon = lon, lat = lat, oprj = oprj))
   }else{
     if(methods::is(x,"Spatial")){
+      warn_sp()
       x <- st_as_sf(x)
     }
     if(is.data.frame(x)){
@@ -249,3 +254,16 @@ input_route <- function(x, id, single = TRUE){
   }
 } 
 
+
+warn_sp <- function(){
+  .Deprecated(
+    msg = paste0("sp support will be dropped in the next release, ",
+                 "please use sf objects instead.")
+  )
+  if (!requireNamespace("sp", quietly = TRUE)) {
+    stop(
+      "'sp' is needed for this function to work. Please install it.",
+      call. = FALSE
+    )
+  }
+}
