@@ -1,3 +1,5 @@
 if ( requireNamespace("tinytest", quietly=TRUE) ){
+  localtest <- FALSE
+  home <- FALSE
   tinytest::test_package("osrm")
 }
